class Error(Exception):
    """Base class for other exceptions """
    pass


class InvalidAuthKeyError(Error):
    """Raised when auth key is invalid"""
    pass

class ImageTooSmallError(Error):
    """Raised when image is too small to compression"""
    pass
	




'''
Mayur Deshmukh

Compression as a Service
Compression Api Wrapper for python

To do
1. Add support for SSL certificate for secured connection
2. Handle more exception

'''

import requests 
import urllib3
from CaaS import errors
import base64


urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

'''Usage

How to call

from caas import text_compression

response = text_compression(filename_to_compress,path_of_file,authorization_key)

Exception Handling

If auth key is invalid then InvalidAuthKeyError exception is raised

To handle 

try:
	response = text_compression(filename_to_compress,path_of_file,authorization_key)
except InvalidAuthKeyError:
	do something

'''	

 


def image_compression(file_to_compress,compressed_file,auth_token):

	filename = file_to_compress.rpartition('/')[-1]
	extension = filename.rpartition('.')[-1]
	if extension == 'jpg' or extension == 'jpeg':
		content_type = 'image/jpeg'
	elif extension == 'png':
		content_type = 'image/png'
	elif extension == 'tiff':
		content_type = 'image/tiff'
	else:
		content_type = 'image/webp'

	url = "https://data-compression-platform.eu-gb.cf.appdomain.cloud/api/v1/image_compression"

	headers = {'auth-token': auth_token, 'Content-Type': content_type}

	with open(file_to_compress,"rb") as f:
		temp = f.read()

	response = requests.post(url,data=temp, headers=headers)

	if response.status_code == 401:
		raise InvalidAuthKeyError

	if response.status_code == 406:
		raise ImageTooSmallError

	data = response.content

	with open(compressed_file,"wb") as out:
		out.write(data)

	return response

def audio_compression(file_to_compress,compressed_file,auth_token):

	filename = file_to_compress.rpartition('/')[-1]
	extension = filename.rpartition('.')[-1]
	if extension == 'mp3':
		content_type = 'audio/mpeg'
	else:
		content_type = 'audio/wav'

	url = "https://data-compression-platform.eu-gb.cf.appdomain.cloud/api/v1/audio_compression"

	headers = {'auth-token': auth_token, 'Content-Type': content_type}

	with open(file_to_compress,"rb") as f:
		temp = f.read()

	response = requests.post(url,data=temp, headers=headers)



	if response.status_code == 401:
		raise InvalidAuthKeyError

	data = response.content

	with open(compressed_file,"wb") as out:
		out.write(data)

	return response

def text_compression(file_to_compress,compressed_file,auth_token):

	filename = file_to_compress.rpartition('/')[-1]

	url = "https://data-compression-platform.eu-gb.cf.appdomain.cloud/api/v1/text_compression_encoder"	
	
	headers = {'auth-token': auth_token}

	with open(file_to_compress,"rb") as f:
		temp = f.read()

	response = requests.post(url,data=temp, headers=headers)


	if response.status_code == 401:
		raise InvalidAuthKeyError

	data = response.content

	with open(compressed_file+'.cmp',"wb") as out:
		out.write(data)

	return response

def text_decompression(file_to_compress,compressed_file,auth_token):

	filename = file_to_compress.rpartition('/')[-1]

	url = "https://data-compression-platform.eu-gb.cf.appdomain.cloud/api/v1/text_compression_decoder"	
	
	headers = {'auth-token': auth_token}

	with open(file_to_compress,"rb") as f:
		temp = f.read()

	response = requests.post(url,data=temp, headers=headers)


	if response.status_code == 401:
		raise InvalidAuthKeyError

	data = response.content

	with open(compressed_file,"wb") as out:
		out.write(data)

	return response

def video_compression(file_to_compress,compressed_file,auth_token):

	filename = file_to_compress.rpartition('/')[-1]

	url = "https://data-compression-platform.eu-gb.cf.appdomain.cloud/api/v1/video_compression"

	headers = {'auth-token': auth_token}

	with open(file_to_compress,"rb") as f:
		temp = f.read()

	response = requests.post(url,data=temp, headers=headers)

	print("Response : ",response)
	print("Response Content : ",response.content)

	if response.status_code == 401:
		raise InvalidAuthKeyError

	data = response.content

	with open(compressed_file,"wb") as out:
		out.write(data)

	return response







# For testing purpose

def test_call(auth_token):

	url = "https://fn.enlight.dev/api/v1/web/kkwbecom05/default/test_auth1/"
	#url = "https://fn.enlight.dev/api/v1/web/kkwbecom05/default/test_api/"
	headers = {'auth-token': auth_token}

	response = requests.post(url, headers=headers, verify=False)


	return response   
    





    




from setuptools import setup
from os import path

setup(
  name = 'CaaS',         # How you named your package folder (MyLib)
  packages = ['CaaS'],   # Chose the same as "name"
  version = '1.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A Python library for Compression as a Service. CaaS can compress images, audio, video, text files ', 
  long_description=open('README.md').read(),
  long_description_content_type="text/markdown",
  author = 'Mayur Deshmukh',                   # Type in your name
  author_email = 'mayur.s.deshmukh10@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/MayurDeshmukh10/CaaS',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/MayurDeshmukh10/CaaS/archive/V_7.tar.gz',    # I explain this later on
  keywords = ['compression', 'image compression', 'video compression', 'audio compression', 'text compression','Compression as a service'],   # Keywords that define your package best
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',  
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)



from CaaS.errors import Error
from CaaS.errors import InvalidAuthKeyError
from CaaS.errors import ImageTooSmallError
from CaaS.caas import image_compression
from CaaS.caas import audio_compression
from CaaS.caas import text_compression
from CaaS.caas import text_decompression
from CaaS.caas import video_compression
from CaaS.caas import image
